% This script runs the Mean centered approach to Task PLSC version of Symmetric PLS.This is the
% same example as described in the paper titled: Partial Least Squares
% (PLS) Methods for Neuroimaging: A Tutorial and Review

clear
clc

%% Load data matrix
%  For the mini-example, we have chosen a hypothetical neuroimaging
%  experiment that compares two clinical populations: Alzheimer's Disease (AD),
%  Parkinson's Disease (PD) and and an age-matched normal control group
%  (NC). Each participant is scanned once using PET imaging. Voxel activity
%  values from the PET scans are collected separately for each participant
%  and stored in matrix X. The scans are co-registered onto a common space.
%  The rows of X are participants AD1, AD2, AD3, PD1, PD2, PD3, NC1, NC2
%  and NC3. 
%  **Change this for your data**

X   =  [2     5     6     1     9     1     7     6     2     1     7     3
        4     1     5     8     8     7     2     8     6     4     8     2
        5     8     7     3     7     1     7     4     5     1     4     3
        3     3     7     6     1     1    10     2     2     1     7     4
        2     3     8     7     1     6     9     1     8     8     1     6
        1     7     3     1     1     3     1     8     1     3     9     5
        9     0     7     1     8     7     4     2     3     6     2     7
        8     0     6     5     9     7     4     4     2    10     3     8
        7     7     4     5     7     6     7     6     5     4     8     8]
    
% The data matrix is actually made of 3 sub-matrices: 
% X1 (AD), X2 (PD), X3 (NC). Each sub-matrix has 3 rows and 12 columns. 
%  **Change this for your data**

X1 = X(1:3,:)
X2 = X(4:6,:)
X3 = X(7:9,:)

%% Load Dummy code
%  The dummy code uses 1s and 0s to code observations into their respsctive
%  groups. For the mini-example, Matrix Y contains the dummy coding where
%  the first column codes for AD, the second column codes for PD and the
%  third column codes for NC.
%  **Change this for your data**

Y = [1     0     0
     1     0     0
     1     0     0
     0     1     0
     0     1     0
     0     1     0
     0     0     1
     0     0     1
     0     0     1]   
 
%% Compute conditon-wise mean matrix 

M = inv(diag(ones(size(Y,1),1)'*Y))*Y'*X

%% Compute the column-wise mean-centered matrix

R = M - ones(size(M,1),1)*((ones(size(M,1),1)'*M)./size(M,1))

%% Singular Value Decomposition
%  Matrx R is decomposed into two sets of singular vectors and one set of 
%  singular values. In the neuroimaging context, the singular vectors are 
%  known as saliences

[U,Delta,V]=paq(R)

%% Latent variables for the brain
%  The latent variables for the brain are computed as the product of X and
%  the saliences for the brain (V)

Lx = X*V

%% Plots
%  The saliences for the brain are project on a glass brain to show brain
%  regions that differentiate between experimental conditons. 

%  The saliences for the design (U) are interpreted as contrasts and can be
%  plotted as bar graphs according to condition separately for each latent
%  variable. We have shown the first 2 saliences for the design (also
%  called Task Saliences)

%  **Change this for your data**

figure()
barmat1=[U(1,1) U(2,1) U(3,1)];
bar(barmat1)
xlabel('Experimental Groups')
set(gca,'XTickLabel',{'AD','PD','NC'})
ylabel('First Task Salience')
title('First Task Salience for all three experimental groups')

figure()
barmat2=[U(1,2) U(2,2) U(3,2)];
bar(barmat2)
xlabel('Experimental Groups')
set(gca,'XTickLabel',{'AD','PD','NC'})
ylabel('Second Task Salience')
title('Second Task Salience for all three experimental groups')

 
